nolearn contains a number of wrappers around existing neural network
libraries, along with a few machine learning utility modules.  Most
functionality is written to be compatible with the the excellent
`scikit-learn <http://scikit-learn.org/>`_ library.

View the `documentation here <http://packages.python.org/nolearn/>`_.
